@@ -1,9 +1,8 @@
 from __future__ import absolute_import, print_function, unicode_literals
 
-import datetime
 import re
 from .render import renderValue
-from .shared import JSONTemplateError, DeleteMarker, TemplateError
+from .shared import JSONTemplateError, DeleteMarker, TemplateError, fromNow
 from . import builtins
 
 _context_re = re.compile(r'[a-zA-Z_][a-zA-Z0-9_]*$')
@@ -12,11 +11,14 @@ _context_re = re.compile(r'[a-zA-Z_][a-zA-Z0-9_]*$')
 def render(template, context):
     if not all(_context_re.match(c) for c in context):
         raise TemplateError('top level keys of context must follow '
-                                '/[a-zA-Z_][a-zA-Z0-9_]*/')
-    full_context = {'now': datetime.datetime.utcnow()}
+                            '/[a-zA-Z_][a-zA-Z0-9_]*/')
+    full_context = {'now': fromNow('0 seconds', None)}
     full_context.update(builtins.build(full_context))
     full_context.update(context)
     rv = renderValue(template, full_context)
     if rv is DeleteMarker:
         return None
+    if callable(rv):
+        raise TemplateError(('$eval {} doesn\'t get any arguments '
+                             'in template').format(template['$eval']))
     return rv
